'use client';
import { jsx, jsxs } from 'react/jsx-runtime';
import { ElementClassNameProvider } from '../system/element-class-name.mjs';
import { ColorModeProvider } from '../color-mode/color-mode-provider.mjs';
import { CSSReset, CSSPolyfill } from '../css-reset/css-reset.mjs';
import { ThemeProvider, GlobalStyle } from '../system/providers.mjs';
import { PortalManager } from '../portal/portal-manager.mjs';
import { EnvironmentProvider } from '../env/env.mjs';

const Provider = (props) => {
  const {
    children,
    colorModeManager,
    portalZIndex,
    resetCSS = true,
    elementClassName = "ch2",
    theme = {},
    environment,
    cssVarsRoot,
    disableEnvironment,
    disableGlobalStyle
  } = props;
  const _children = /* @__PURE__ */ jsx(
    EnvironmentProvider,
    {
      environment,
      disabled: disableEnvironment,
      children
    }
  );
  return /* @__PURE__ */ jsx(ElementClassNameProvider, { value: elementClassName, children: /* @__PURE__ */ jsx(ThemeProvider, { theme, cssVarsRoot, children: /* @__PURE__ */ jsxs(
    ColorModeProvider,
    {
      colorModeManager,
      options: theme.config,
      children: [
        resetCSS ? /* @__PURE__ */ jsx(CSSReset, { elementClassName }) : /* @__PURE__ */ jsx(CSSPolyfill, {}),
        !disableGlobalStyle && /* @__PURE__ */ jsx(GlobalStyle, {}),
        portalZIndex ? /* @__PURE__ */ jsx(PortalManager, { zIndex: portalZIndex, children: _children }) : _children
      ]
    }
  ) }) });
};

export { Provider };
