'use client';
import { isStyleProp, css } from '@chakra-v2/styled-system';
import { interopDefault, splitProps, runIfFn, assignAfter, compact, cx } from '@chakra-v2/utils';
import createStyled from '@emotion/styled';
import { forwardRef, createElement } from 'react';
import { shouldForwardProp } from './should-forward-prop.mjs';
import { useElementClassName } from './element-class-name.mjs';
import { useColorMode } from '../color-mode/color-mode-context.mjs';

const emotion_styled = interopDefault(createStyled);
const toCSSObject = ({ baseStyle }) => (props) => {
  const { theme, css: cssProp, __css, sx, ...restProps } = props;
  const [styleProps] = splitProps(restProps, isStyleProp);
  const finalBaseStyle = runIfFn(baseStyle, props);
  const finalStyles = assignAfter(
    {},
    __css,
    finalBaseStyle,
    compact(styleProps),
    sx
  );
  const computedCSS = css(finalStyles)(props.theme);
  return cssProp ? [computedCSS, cssProp] : computedCSS;
};
function styled(component, options) {
  const { baseStyle, ...styledOptions } = options ?? {};
  if (!styledOptions.shouldForwardProp) {
    styledOptions.shouldForwardProp = shouldForwardProp;
  }
  const styleObject = toCSSObject({ baseStyle });
  const Component = emotion_styled(
    component,
    styledOptions
  )(styleObject);
  const chakraComponent = forwardRef(
    function ChakraComponent2(props, ref) {
      const { colorMode, forced } = useColorMode();
      const elementClassName = useElementClassName();
      const { children, ...restProps } = props;
      restProps.className = cx(elementClassName, restProps.className);
      const dataTheme = forced ? colorMode : void 0;
      return createElement(
        Component,
        {
          ref,
          "data-theme": dataTheme,
          ...restProps
        },
        children
      );
    }
  );
  return chakraComponent;
}

export { styled, toCSSObject };
